function plotdt(node, nodeID, figName)
% node: n-by-2
% nodeID: n-by-1
% figName: a string
%
% example: 
%%%% change node and nodeID for your own use
% node = [1 4; 5 5; 3 7; 6 1; 8 10]; % assignment statement creating coordinates of nodes separated by
% semicolon
% nodeID = [5 9 11 2 4]; % assignment statement creating node IDs in the same
% order
% plotdt(node, nodeID, 'A DT Example') % change 'A DT Example' to title of
% your figure

figure
tri = delaunay(node(:,1), node(:,2));
triplot(tri, node(:,1), node(:,2));
hold on
for i1 = 1:1:length(nodeID)
    plot(node(i1, 1), node(i1,2), 'ro','MarkerFaceColor','r');
    text(node(i1, 1) + 0.3, node(i1,2) + 0.3, num2str(nodeID(i1)), 'FontSize', 14)
end

box on
set(gca, 'XTick', [])
set(gca, 'YTick', [])
axis([0 18 -1 11]) % specify maximum and minimum values of coordinates suitable for this problem assignment
xlabel(figName, 'FontSize', 14)

end